@@ -9,6 +9,7 @@ from rdflib import Graph
 from yaml.constructor import ConstructorError
 
 from linkml_runtime.utils.context_utils import CONTEXTS_PARAM_TYPE, merge_contexts
+from linkml_runtime.utils.formatutils import is_empty
 
 YAMLObjTypes = Union[JsonObjTypes, "YAMLRoot"]
 
@@ -88,7 +89,8 @@ class YAMLRoot(JsonObj):
 
     @staticmethod
     def _is_empty(v: Any) -> bool:
-        return v is None or (isinstance(v, (dict, list)) and not v) or (isinstance(v, JsonObj) and not as_dict(v))
+        # TODO: Deprecate this function and migrate the python generator over to the stand alone is_empty
+        return is_empty(v)
 
     def _normalize_inlined_as_list(self, slot_name: str, slot_type: Type, key_name: str, keyed: bool) -> None:
         self._normalize_inlined(slot_name, slot_type, key_name, keyed, True)
